pub(crate) struct ValueBuilder {
timestamp: Vec<i64>,
timestamp_type: ConcreteDataType,
sequence: Vec<u64>,
op_type: Vec<u8>,
fields: Vec<Option<FieldBuilder>>,
field_schemas: Vec<ColumnSchema>,
}Expand description
ValueBuilder holds all the vector builders for field columns.
Fields
timestamp: Vec<i64>timestamp_type: ConcreteDataTypesequence: Vec<u64>op_type: Vec<u8>fields: Vec<Option<FieldBuilder>>field_schemas: Vec<ColumnSchema>Implementations
Sourceimpl ValueBuilder
impl ValueBuilder
pub(crate) fn new(region_metadata: &RegionMetadataRef, capacity: usize) -> Self
Sourcepub fn num_field_builders(&self) -> usize
pub fn num_field_builders(&self) -> usize
Returns number of field builders.
Sourcepub(crate) fn push<'a>(
&mut self,
ts: ValueRef<'_>,
sequence: u64,
op_type: u8,
fields: impl Iterator<Item = ValueRef<'a>>,
) -> usize
pub(crate) fn push<'a>( &mut self, ts: ValueRef<'_>, sequence: u64, op_type: u8, fields: impl Iterator<Item = ValueRef<'a>>, ) -> usize
Pushes a new row to ValueBuilder.
We don’t need primary keys since they’ve already be encoded.
Returns the size of field values.
In this method, we don’t check the data type of the value, because it is already checked in the caller.
Sourcepub(crate) fn can_accommodate(&self, fields: &[VectorRef]) -> Result<bool>
pub(crate) fn can_accommodate(&self, fields: &[VectorRef]) -> Result<bool>
Checks if current value builder have sufficient space to accommodate fields.
Returns Ok(false) if the current builder lacks the remaining space to accommodate
the fields due to offset overflow, but an empty builder would be able to accommodate
the batch (the caller may freeze the current builder and replay the batch onto an
empty one).
Returns Err(InvalidBatchSnafu) if the string data of a single batch itself exceeds
the Arrow string array offset limit and thus can never be accommodated, not even by an
empty builder.
pub(crate) fn extend( &mut self, ts_v: VectorRef, op_type: u8, sequence: u64, fields: Vec<VectorRef>, ) -> Result<()>
Sourcefn len(&self) -> usize
fn len(&self) -> usize
Returns the length of ValueBuilder
fn finish_cloned(&self) -> Values